@@ -1,5 +1,6 @@
 import datetime
 import logging
+from logging.handlers import RotatingFileHandler
 from multiprocessing import Process, Queue
 import os
 from pathlib import Path
@@ -49,20 +50,18 @@ CAMERA_V_FLIP = os.environ.get("CAMERA_V_FLIP", 0)
 METRICS_LOG_DIR = Path(os.environ.get("METRICS_LOG", "/var/log/wf_metrics"))
 
 def get_logger(name):
-    logger = logging.getLogger("wf_metrics")
-    METRICS_LOG_DIR = Path(os.environ.get("METRICS_LOG", "./wf_metrics"))
+    metlogger = logging.getLogger("wf_metrics")
     if not METRICS_LOG_DIR.exists():
         METRICS_LOG_DIR.mkdir()
     path = METRICS_LOG_DIR / f"{name}.log"
-    logger.setLevel(logging.INFO)
+    metlogger.setLevel(logging.INFO)
     handy = RotatingFileHandler(path, maxBytes=20000000, backupCount=5)
     handy.setFormatter(logging.Formatter())
-    logger.addHandler(handy)
-    return logger
+    metlogger.addHandler(handy)
+    return metlogger
 
 def emit(metlog, name, values, tags=None):
     metric = Metric(name)
-    client.metric(name, values, tags=tags)
     metric.with_timestamp(time.time() * 1000000000)
     for tag in tags:
         metric.add_tag(tag, tags[tag])
